| writeAlizer-package | R Documentation |
Package-level documentation for writeAlizer.
Detailed documentation on writeAlizer is available in the GitHub README file and getting-started guide.
The writeAlizer R package (a) imports ReaderBench, Coh-Metrix, and GAMET output files into R, and (b) uses research-developed scoring models to generate predicted writing quality scores or Total Words Written, Words Spelled Correctly, Correct Word Sequences, and Correct Minus Incorrect Word Sequences scores from GAMET files.
The writeAlizer package includes functions to do two types of tasks: (1) importing ReaderBench, Coh-Metrix, and/or GAMET output files into R; and (2) generating predicted quality scores using the imported output files. There are also additional functions to help with (3) identifying optional package dependencies and (4) cache management.
import_rb
import_coh
import_gamet
import_merge_gamet_rb
predict_quality
model_deps
wa_cache_dir
wa_cache_clear
Maintainer: Sterett H. Mercer sterett.mercer@ubc.ca (ORCID)
Authors:
Sterett H. Mercer sterett.mercer@ubc.ca (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.